"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getReactNativeConfiguration = getReactNativeConfiguration;
exports.createConfig = createConfig;
exports.webpackMerge = exports.defaultOptions = void 0;

var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _fs = require("fs");

var _path = _interopRequireWildcard(require("path"));

var _parseAuthor = _interopRequireDefault(require("parse-author"));

var _webpack = _interopRequireDefault(require("webpack"));

var _webpackMerge = _interopRequireDefault(require("webpack-merge"));

var _miniHtmlWebpackPlugin = require("mini-html-webpack-plugin");

var _env = require("@expo/webpack-config/env");

var _loaders = _interopRequireDefault(require("./loaders"));

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { (0, _defineProperty2.default)(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function getReactNativeConfiguration() {
  return {
    resolve: {
      alias: _objectSpread({
        react$: require.resolve('react'),
        'react-dom$': require.resolve('react-dom'),
        './RNGestureHandlerModule': (0, _path.join)(process.cwd(), 'node_modules', 'react-native-gesture-handler', 'RNGestureHandlerModule.web.js'),
        './GestureHandlerButton': (0, _path.join)(process.cwd(), 'node_modules', 'react-native-gesture-handler', 'GestureHandlerButton.web.js'),
        './GestureComponents': (0, _path.join)(process.cwd(), 'node_modules', 'react-native-gesture-handler', 'GestureComponents.web.js'),
        './PlatformConstants': (0, _path.join)(process.cwd(), 'node_modules', 'react-native-gesture-handler', 'PlatformConstants.web.js'),
        './resolveAssetSource': (0, _path.join)(process.cwd(), 'node_modules', 'expo-asset', 'build', 'resolveAssetSource.web.js'),
        './EmbeddedAssets': (0, _path.join)(process.cwd(), 'node_modules', 'expo-asset', 'build', 'EmbeddedAssets.web.js'),
        './AssetSourceResolver': (0, _path.join)(process.cwd(), 'node_modules', 'expo-asset', 'build', 'AssetSourceResolver.web.js'),
        './AssetRegistry': (0, _path.join)(process.cwd(), 'node_modules', 'expo-asset', 'build', 'AssetRegistry.web.js')
      }, _env.aliases),
      extensions: ['.web.js', '.js']
    },
    module: {
      rules: [{
        test: /\.js$/,
        loader: 'babel-loader',
        exclude: /node_modules[/\\](?!react-native|react-native-paper|react-native-vector-icons|react-native-safe-area-view|react-native-gesture-handler|react-clone-referenced-element|@react-native-community|expo(nent)?|@expo(nent)?\/.*|react-navigation|@react-navigation\/.*|@unimodules\/.*|unimodules-*|sentry-expo|native-base)/,
        options: {
          plugins: ['@babel/proposal-class-properties', '@babel/proposal-object-rest-spread', 'react-native-web'],
          presets: ['@babel/preset-env', 'module:metro-react-native-babel-preset'],
          babelrc: false,
          configFile: false
        }
      }, {
        test: /\.(jpe?g|png|gif)$/i,
        use: [{
          loader: 'file-loader',
          options: {
            hash: 'sha512',
            digest: 'hex',
            name: '[hash].[ext]'
          }
        }]
      }, {
        test: /\.ttf$/,
        loader: 'file-loader'
      }]
    },
    plugins: [new _webpack.default.DefinePlugin({
      __DEV__: process.env
    })]
  };
}

var defaultOptions = {
  layout: null,
  layoutPath: 'lib/Layout/index.js',
  wrapperPath: 'lib/Wrapper/index.js',
  styleguideConfigPath: 'lib/styleguide.config.js',
  loadersConfigPath: 'lib/loaders/index.js',
  faviconConfigPath: 'lib/favicons/index.js',
  styleGuideDirPath: 'styleguide',
  extensionFile: 'styleguide.ext.json',
  setupFile: 'setup.js',
  optionsPath: 'lib/options.js',
  licensePath: 'LICENSE.md',
  locale: 'en',
  loader: Object.keys(_loaders.default)[0],
  loaders: _loaders.default,
  loaderInnerApp: true,
  favicon: null,
  favicons: {},
  head: null,
  disableAutoConf: false,
  themeColor: null,
  reactNative: true
};
exports.defaultOptions = defaultOptions;
var webpackMerge = _webpackMerge.default;
exports.webpackMerge = webpackMerge;

function retrieveComponentsApiPath(defaultStyleGuidePath, defaultWrapperPath, pkg, thisPkg, base, opts) {
  var finalStyleGuidePath = defaultStyleGuidePath;
  var finalWrapperPath = defaultWrapperPath;
  var finalConfigExtension = {};
  var finalLoadersExtension = {};
  var finalFaviconExtension = {};
  var finalOptionsExtension = {};
  var found = false;

  if (!opts.disableAutoConf) {
    [pkg.dependencies || {}, pkg.devDependencies || {}].forEach(function (o) {
      Object.keys(o).forEach(function (dep) {
        if (dep.includes('documentation') && !dep.includes(thisPkg.name)) {
          var _require = require((0, _path.join)(base, 'node_modules', dep, 'package.json')),
              keywords = _require.keywords;

          if (keywords && keywords.indexOf(thisPkg.name) !== -1) {
            if ((0, _fs.existsSync)((0, _path.join)(base, 'node_modules', dep, opts.layoutPath))) {
              finalStyleGuidePath = (0, _path.join)(base, 'node_modules', dep, opts.layoutPath);
              found = dep;
            }

            if ((0, _fs.existsSync)((0, _path.join)(base, 'node_modules', dep, opts.wrapperPath))) {
              finalWrapperPath = (0, _path.join)(base, 'node_modules', dep, opts.wrapperPath);
              found = dep;
            }

            if ((0, _fs.existsSync)((0, _path.join)(base, 'node_modules', dep, opts.styleguideConfigPath))) {
              finalConfigExtension = require((0, _path.join)(base, 'node_modules', dep, opts.styleguideConfigPath));
              found = dep;
            }

            if ((0, _fs.existsSync)((0, _path.join)(base, 'node_modules', dep, opts.loadersConfigPath))) {
              finalLoadersExtension = require((0, _path.join)(base, 'node_modules', dep, opts.loadersConfigPath));
              found = dep;
            }

            if ((0, _fs.existsSync)((0, _path.join)(base, 'node_modules', dep, opts.faviconConfigPath))) {
              finalFaviconExtension = require((0, _path.join)(base, 'node_modules', dep, opts.faviconConfigPath));
              found = dep;
            }

            if ((0, _fs.existsSync)((0, _path.join)(base, 'node_modules', dep, opts.optionsPath))) {
              finalOptionsExtension = require((0, _path.join)(base, 'node_modules', dep, opts.optionsPath));
              found = dep;
            }
          }
        }
      });

      if (found) {
        console.log("Auto configuration with ".concat(found));
      }
    });
  }

  if (!found && opts.layout && (0, _fs.existsSync)((0, _path.join)(base, 'node_modules', opts.layout))) {
    if ((0, _fs.existsSync)((0, _path.join)(base, 'node_modules', opts.layout, opts.layoutPath))) {
      finalStyleGuidePath = (0, _path.join)(base, 'node_modules', opts.layout, opts.layoutPath);
      found = true;
    }

    if ((0, _fs.existsSync)((0, _path.join)(base, 'node_modules', opts.layout, opts.wrapperPath))) {
      finalWrapperPath = (0, _path.join)(base, 'node_modules', opts.layout, opts.wrapperPath);
      found = true;
    }

    if ((0, _fs.existsSync)((0, _path.join)(base, 'node_modules', opts.layout, opts.styleguideConfigPath))) {
      finalConfigExtension = require((0, _path.join)(base, 'node_modules', opts.layout, opts.styleguideConfigPath));
      found = true;
    }

    if ((0, _fs.existsSync)((0, _path.join)(base, 'node_modules', opts.layout, opts.loadersConfigPath))) {
      finalLoadersExtension = require((0, _path.join)(base, 'node_modules', opts.layout, opts.loadersConfigPath));
      found = true;
    }

    if ((0, _fs.existsSync)((0, _path.join)(base, 'node_modules', opts.layout, opts.faviconConfigPath))) {
      finalFaviconExtension = require((0, _path.join)(base, 'node_modules', opts.layout, opts.faviconConfigPath));
      found = true;
    }

    if ((0, _fs.existsSync)((0, _path.join)(base, 'node_modules', opts.layout, opts.optionsPath))) {
      finalOptionsExtension = require((0, _path.join)(base, 'node_modules', opts.layout, opts.optionsPath));
      found = true;
    }

    if (!found) {
      console.log("We cannot find the layout for package ".concat(opts.layout, ", it must be installed."));
    }
  }

  if ((0, _fs.existsSync)((0, _path.join)(base, 'styleguide/components'))) {
    if ((0, _fs.existsSync)((0, _path.join)(base, 'styleguide/components/Layout.js'))) {
      finalStyleGuidePath = (0, _path.join)(base, 'styleguide/components/Layout.js');
    }

    if ((0, _fs.existsSync)((0, _path.join)(base, 'styleguide/components/Wrapper.js'))) {
      finalWrapperPath = (0, _path.join)(base, 'styleguide/components/Wrapper.js');
    }
  }

  return {
    finalStyleGuidePath: finalStyleGuidePath,
    finalWrapperPath: finalWrapperPath,
    finalConfigExtension: finalConfigExtension,
    finalLoadersExtension: finalLoadersExtension,
    finalFaviconExtension: finalFaviconExtension,
    finalOptionsExtension: finalOptionsExtension
  };
}

function createConfig() {
  var config = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var userWebpackConfig = config.webpackConfig,
      userRequireConfig = config.require,
      userStyleguideComponents = config.styleguideComponents,
      userConfig = (0, _objectWithoutProperties2.default)(config, ["webpackConfig", "require", "styleguideComponents"]);

  var opts = _objectSpread({}, defaultOptions, {}, options);

  var cwd = process.cwd();
  var base = (0, _fs.existsSync)((0, _path.join)(cwd, 'package.json')) ? (0, _path.join)(cwd) : (0, _path.join)(__dirname, '..');
  var extension = (0, _fs.existsSync)((0, _path.join)(base, opts.styleGuideDirPath, opts.extensionFile)) ? require(_path.default.join(base, opts.styleGuideDirPath, opts.extensionFile)) : {};
  var thisPkgPath = (0, _path.join)(__dirname, '../package.json');
  var thisPkg = (0, _fs.existsSync)(thisPkgPath) ? require(thisPkgPath) : {};

  var pkg = require((0, _path.join)(base, 'package.json'));

  var licensePath = (0, _fs.existsSync)((0, _path.join)(base, opts.licensePath)) ? (0, _path.join)(base, opts.licensePath) : (0, _path.join)(base, opts.licensePath);
  var license = (0, _fs.existsSync)(licensePath) ? (0, _fs.readFileSync)(licensePath, {
    encoding: 'utf8'
  }).split('\n')[0] : console.log("".concat(opts.licensePath, " is missing!"));
  var requireConfig = [];

  if ((0, _fs.existsSync)((0, _path.resolve)(base, opts.styleGuideDirPath, opts.setupFile))) {
    requireConfig.push((0, _path.resolve)(base, opts.styleGuideDirPath, opts.setupFile));
  }

  var defaultStyleGuidePath = (0, _fs.existsSync)((0, _path.join)(__dirname, '../src/Layout')) ? (0, _path.join)(__dirname, '../src/Layout') : (0, _path.join)(__dirname, '../lib/Layout');
  var defaultWrapperPath = (0, _fs.existsSync)((0, _path.join)(__dirname, '../src/Wrapper')) ? (0, _path.join)(__dirname, '../src/Wrapper') : (0, _path.join)(__dirname, '../lib/Wrapper');

  var _retrieveComponentsAp = retrieveComponentsApiPath(defaultStyleGuidePath, defaultWrapperPath, pkg, thisPkg, base, opts),
      finalStyleGuidePath = _retrieveComponentsAp.finalStyleGuidePath,
      finalWrapperPath = _retrieveComponentsAp.finalWrapperPath,
      finalConfigExtension = _retrieveComponentsAp.finalConfigExtension,
      finalLoadersExtension = _retrieveComponentsAp.finalLoadersExtension,
      finalFaviconExtension = _retrieveComponentsAp.finalFaviconExtension,
      finalOptionsExtension = _retrieveComponentsAp.finalOptionsExtension;

  var finalWebpackConfig = finalConfigExtension.webpackConfig,
      finalStyleguideComponents = finalConfigExtension.styleguideComponents,
      finalRequireConfig = finalConfigExtension.require,
      finalConfig = (0, _objectWithoutProperties2.default)(finalConfigExtension, ["webpackConfig", "styleguideComponents", "require"]);
  opts = _objectSpread({}, opts, {}, finalOptionsExtension);

  var loaders = _objectSpread({}, opts.loaders, {}, finalLoadersExtension || {});

  var _opts = opts,
      loader = _opts.loader;

  if (Object.keys(finalLoadersExtension || {}).length && opts.loader === defaultOptions.loader) {
    loader = Object.keys(finalLoadersExtension)[0];
  }

  var favicons = _objectSpread({}, opts.favicons, {}, finalFaviconExtension || {});

  var _opts2 = opts,
      favicon = _opts2.favicon;

  if (Object.keys(finalFaviconExtension || {}).length && opts.favicon === defaultOptions.favicon) {
    favicon = Object.keys(finalFaviconExtension)[0];
  }

  var moduleAliases = (0, _defineProperty2.default)({
    $PACKAGE_NAME: (0, _path.resolve)(base)
  }, pkg.name, (0, _path.resolve)(base));
  var webpackConfig = webpackMerge({
    plugins: [new _webpack.default.SourceMapDevToolPlugin({
      filename: '[file].map',
      exclude: ['node_modules/**/*.js']
    }), new _webpack.default.DefinePlugin({
      'process.env.NODE_ENV': JSON.stringify(process.env.NODE_ENV),
      'process.env.GA_TRACKING_ID': JSON.stringify(process.env.GA_TRACKING_ID)
    })],
    resolve: {
      alias: moduleAliases
    },
    module: {
      rules: [{
        test: /\.jsx?$/,
        exclude: /node_modules/,
        include: [(0, _path.resolve)((0, _path.join)(cwd, 'src')), (0, _path.resolve)((0, _path.join)(cwd, opts.styleGuideDirPath))],
        loader: 'babel-loader'
      }, {
        test: /\.css$/,
        use: ['style-loader', 'css-loader']
      }, {
        test: /\.(jpe?g|png|gif)$/,
        use: [{
          loader: 'url-loader',
          options: {
            limit: 10 * 1024
          }
        }, {
          loader: 'image-webpack-loader',
          options: {
            mozjpeg: {
              enabled: false
            },
            gifsicle: {
              interlaced: false
            },
            optipng: {
              optimizationLevel: 7
            },
            pngquant: {
              quality: [0.65, 0.90],
              speed: 4
            }
          }
        }]
      }, {
        test: /\.(mp4|webm)$/,
        use: {
          loader: 'url-loader',
          options: {
            limit: 10000
          }
        }
      }]
    }
  }, finalWebpackConfig || {}, opts.reactNative ? getReactNativeConfiguration() : {}, userWebpackConfig || {});

  var styleguideComponents = _objectSpread({}, _objectSpread({
    StyleGuideRenderer: finalStyleGuidePath,
    Wrapper: finalWrapperPath,
    ArgumentRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Argument/ArgumentRenderer.js'),
    ArgumentsRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Arguments/ArgumentsRenderer.js'),
    CodeRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Code/CodeRenderer.js'),
    ComponentsRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Components/ComponentsRenderer.js'),
    ComponentsList: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/ComponentsList/ComponentsList.js'),
    ComponentsListRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/ComponentsList/ComponentsListRenderer.js'),
    Editor: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Editor/Editor.js'),
    EditorLoaderRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Editor/EditorLoaderRenderer.js'),
    ErrorRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Error/ErrorRenderer.js'),
    ExamplePlaceholderRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/ExamplePlaceholder/ExamplePlaceholderRenderer.js'),
    ExamplesRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Examples/ExamplesRenderer.js'),
    HeadingRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Heading/HeadingRenderer.js'),
    LinkRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Link/LinkRenderer.js'),
    LogoRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Logo/LogoRenderer.js'),
    Markdown: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Markdown'),
    Blockquote: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Markdown/Blockquote'),
    BlockquoteRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Markdown/Blockquote/BlockquoteRenderer.js'),
    Checkbox: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Markdown/Checkbox'),
    CheckboxRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Markdown/Checkbox/CheckboxRenderer.js'),
    Hr: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Markdown/Hr'),
    HrRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Markdown/Hr/HrRenderer.js'),
    JsDoc: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/JsDoc'),
    List: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Markdown/List'),
    ListRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Markdown/List/ListRenderer.js'),
    MarkdownHeading: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Markdown/MarkdownHeading'),
    MarkdownHeadingRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Markdown/MarkdownHeading/MarkdownHeadingRenderer.js'),
    Pre: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Markdown/Pre'),
    PreRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Markdown/Pre/PreRenderer.js'),
    TableHeadRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Markdown/Table/TableHeadRenderer.js'),
    TableBodyRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Markdown/Table/TableBodyRenderer.js'),
    TableRowRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Markdown/Table/TableRowRenderer.js'),
    TableCellRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Markdown/Table/TableCellRenderer.js'),
    MessageRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Message/MessageRenderer.js'),
    MethodsRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Methods/MethodsRenderer.js'),
    NameRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Name/NameRenderer.js'),
    ParaRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Para/ParaRenderer.js'),
    PathlineRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Pathline/PathlineRenderer.js'),
    PlaygroundRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Playground/PlaygroundRenderer.js'),
    PlaygroundErrorRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/PlaygroundError/PlaygroundErrorRenderer.js'),
    ReactComponentRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/ReactComponent/ReactComponentRenderer.js'),
    RibbonRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Ribbon/RibbonRenderer.js'),
    SectionRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Section/SectionRenderer.js'),
    SectionHeadingRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/SectionHeading/SectionHeadingRenderer.js'),
    SectionsRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Sections/SectionsRenderer.js'),
    slots: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/slots'),
    TabButtonRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/TabButton/TabButtonRenderer.js'),
    TableRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Table/TableRenderer.js'),
    TableOfContents: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/TableOfContents/TableOfContents'),
    TableOfContentsRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/TableOfContents/TableOfContentsRenderer.js'),
    TextRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Text/TextRenderer.js'),
    ToolbarButtonRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/ToolbarButton/ToolbarButtonRenderer.js'),
    TypeRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Type/TypeRenderer.js'),
    Usage: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Usage/Usage.js'),
    VersionRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Version/VersionRenderer.js'),
    WelcomeRenderer: (0, _path.join)(base, 'node_modules/@bootstrap-styled/rsg-components/lib/Welcome/WelcomeRenderer.js')
  }, finalStyleguideComponents || {}, {}, userStyleguideComponents || {}));

  return _objectSpread({
    serverPort: process.env.NODE_PORT ? parseInt(process.env.NODE_PORT, 10) : 6060,
    require: ['@babel/polyfill'].concat(requireConfig, (0, _toConsumableArray2.default)(finalRequireConfig || []), (0, _toConsumableArray2.default)(userRequireConfig || [])),
    styleguideDir: 'public',
    components: ['src/components/**/[A-Z]*.js', 'src/components/**/[A-Z]*/index.js'],
    previewDelay: 500,
    skipComponentsWithoutExample: false,
    exampleMode: 'expand',
    usageMode: 'expand',
    showSidebar: true,
    styles: {},
    title: pkg.name,
    verbose: false,
    version: pkg.version,
    getComponentPathLine: function getComponentPathLine(componentPath) {
      var name = '';
      var ext = '';
      var key = null;

      if (/.js$/.test(componentPath)) {
        name = (0, _path.basename)(componentPath, '.js');
      } else if (/.svg$/.test(componentPath)) {
        name = (0, _path.basename)(componentPath, '.svg');
        key = 'ReactComponent';
        ext = '.svg';
      }

      var dir = name === 'index' ? (0, _path.dirname)(componentPath) : "".concat((0, _path.dirname)(componentPath), "/").concat(name);
      name = name === 'index' ? (0, _path.basename)(dir) : name;
      var es6import = key ? "{ ".concat(key, " as ").concat(name[0].toUpperCase()).concat(name.slice(1), " }") : name;
      return "import ".concat(es6import, " from '").concat(pkg.name, "/").concat(dir.replace(/^src\//, 'lib/')).concat(ext, "';");
    },
    updateExample: function updateExample(props) {
      var settings = props.settings,
          lang = props.lang;

      if (lang === 'javascript') {
        settings.static = true;
      }

      return props;
    },
    template: function template(_ref) {
      var css = _ref.css,
          js = _ref.js,
          title = _ref.title,
          publicPath = _ref.publicPath;
      return "<!DOCTYPE html>\n    <html lang=\"".concat(opts.locale, "\">\n      <head>\n        <meta charset=\"UTF-8\">\n        <meta name=\"viewport\" content=\"width=device-width, initial-scale=1.0\" />\n        <meta name=\"description\" content=\"").concat(pkg.description, "\">\n        ").concat(pkg.keywords && pkg.keywords.length > 0 ? "<meta name=\"keywords\" content=\"".concat(pkg.keywords.join(','), "\">") : '', "\n        <meta name=\"author\" content=\"").concat((0, _parseAuthor.default)(pkg.author).name, "\">\n        ").concat(license ? "<meta name=\"copyright\" content=\"".concat(license, "\" />") : '', "\n        ").concat(pkg.contributor && pkg.contributor.length > 0 ? "<meta name=\"contributor\" content=\"".concat(pkg.contributor.map(function (c) {
        return (0, _parseAuthor.default)(c).name;
      }).join(','), "\">") : '', "\n        ").concat(pkg.private === undefined ? '<meta name="robots" content="index,follow"/>' : '', "\n        ").concat(pkg.private === false ? '<meta name="robots" content="nofollow"/>' : '', "\n        ").concat(pkg.private === true ? '<meta name="robots" content="noindex, nofollow"/>' : '', "\n        ").concat(pkg.name !== thisPkg.name ? "<meta name=\"".concat(thisPkg.name, "-version\" content=\"").concat(thisPkg.version, "\">\n<meta name=\"version\" content=\"").concat(pkg.version, "\">") : "<meta name=\"version\" content=\"".concat(pkg.version, "\">"), "\n        ").concat(favicon ? "<link rel=\"icon\" type=\"image/x-icon\" href=\"".concat(favicons[favicon], "\">") : '', "\n        ").concat(opts.themeColor ? "<meta name=\"theme-color\" content=\"".concat(opts.themeColor, "\" />") : '', "\n        ").concat(opts.head ? opts.head : '', "\n        <title>").concat(title, "</title>\n        ").concat((0, _miniHtmlWebpackPlugin.generateCSSReferences)(css, publicPath), "\n      </head>\n      <body>\n      ").concat(!opts.loaderInnerApp ? loaders[loader] : '', "\n      <div id=\"rsg-root\">").concat(opts.loaderInnerApp ? loaders[loader] : '', "</div>\n      ").concat((0, _miniHtmlWebpackPlugin.generateJSReferences)(js, publicPath), "\n      </body>\n    </html>");
    },
    styleguideComponents: styleguideComponents,
    webpackConfig: webpackConfig
  }, finalConfig, {}, extension, {}, userConfig);
}